.. rst-class:: detail

SetMaxSpeed
======================

.. currentmodule:: compas_rrc

.. autoclass:: SetMaxSpeed

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~SetMaxSpeed.__init__
        ~SetMaxSpeed.from_msg
    
    